@@ -34,7 +34,11 @@ class Consumer(Base):
         self.set_listener(self.listener_name, self.listener_class(self))
 
     def message_handler(self, body, headers):
-        body = json.loads(body)
+        try:
+            body = json.loads(body)
+        except json.JSONDecodeError as exc:
+            logger.exception(exc)
+
         payload = Payload(self.connection, body, headers)
         received, created = self.received_class.objects.get_or_create(msg_id=_get_msg_id(headers))
         if created:
